==> nifi-2.0.0-source-release.zip: nifi-2.0.0/nifi-frontend/src/main/frontend/apps/nifi/src/app/pages/flow-designer/state/flow-analysis/index.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { PropertyDescriptor, Bundle, Permissions } from '../../../../state/shared';

export const flowAnalysisFeatureKey = 'flowAnalysis';

export interface FlowAnalysisRule {
    id: string;
    name: string;
    type: string;
    bundle: Bundle;
    state: string;
    comments?: string;
    persistsState: boolean;
    restricted: boolean;
    deprecated: boolean;
    extensionMissing: boolean;
    multipleVersionsAvailable: boolean;
    supportsSensitiveDynamicProperties: boolean;
    enforcementPolicy: string;
    properties: { [key: string]: string };
    descriptors: { [key: string]: PropertyDescriptor };
    sensitiveDynamicPropertyNames: string[];
    validationErrors: string[];
    validationStatus: 'VALID' | 'INVALID' | 'VALIDATING';
}

export interface FlowAnalysisRuleViolation {
    enforcementPolicy: string;
    scope: string;
    subjectId: string;
    subjectDisplayName: string;
    groupId: string;
    ruleId: string;
    issueId: string;
    violationMessage: string;
    subjectComponentType: string;
    subjectPermissionDto: Permissions;
    enabled: boolean;
}

export interface FlowAnalysisRequestResponse {
    rules: FlowAnalysisRule[];
    ruleViolations: FlowAnalysisRuleViolation[];
    flowAnalysisPending: boolean;
}

export interface FlowAnalysisState {
    rules: FlowAnalysisRule[];
    ruleViolations: FlowAnalysisRuleViolation[];
    flowAnalysisPending: boolean;
    status: 'pending' | 'loading' | 'success';
}

==> nifi-2.6.0-source-release.zip: nifi-2.6.0/nifi-frontend/src/main/frontend/apps/nifi/src/app/pages/flow-designer/state/flow-analysis/index.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { PropertyDescriptor, Bundle } from '../../../../state/shared';
import { Permissions } from '@nifi/shared';

export const flowAnalysisFeatureKey = 'flowAnalysis';

export interface FlowAnalysisRule {
    id: string;
    name: string;
    type: string;
    bundle: Bundle;
    state: string;
    comments?: string;
    persistsState: boolean;
    restricted: boolean;
    deprecated: boolean;
    extensionMissing: boolean;
    multipleVersionsAvailable: boolean;
    supportsSensitiveDynamicProperties: boolean;
    enforcementPolicy: string;
    properties: { [key: string]: string };
    descriptors: { [key: string]: PropertyDescriptor };
    sensitiveDynamicPropertyNames: string[];
    validationErrors: string[];
    validationStatus: 'VALID' | 'INVALID' | 'VALIDATING';
}

export interface FlowAnalysisRuleViolation {
    enforcementPolicy: string;
    scope: string;
    subjectId: string;
    subjectDisplayName: string;
    groupId: string;
    ruleId: string;
    issueId: string;
    violationMessage: string;
    subjectComponentType: string;
    subjectPermissionDto: Permissions;
    enabled: boolean;
}

export interface FlowAnalysisRequestResponse {
    rules: FlowAnalysisRule[];
    ruleViolations: FlowAnalysisRuleViolation[];
    flowAnalysisPending: boolean;
}

export interface FlowAnalysisState {
    rules: FlowAnalysisRule[];
    ruleViolations: FlowAnalysisRuleViolation[];
    flowAnalysisPending: boolean;
    status: 'pending' | 'loading' | 'success';
}
